Package: autotestR
Title: Automated Functions for Basic Statistical Tests
Version: 1.2.15
Authors@R: 
    person("Luiz", "Garcia", 
           email = "luiz.cardoso@ufpr.br", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-9616-0927"))
Description: Provides simple and intuitive functions for basic statistical analyses. 
    Methods include the t-test (Student 1908 <doi:10.1093/biomet/6.1.1>),
    the Mann-Whitney U test (Mann and Whitney 1947 <doi:10.1214/aoms/1177730491>),
    Pearson's correlation (Pearson 1895 <doi:10.1098/rspl.1895.0041>),
    and analysis of variance (Fisher 1925, <doi:10.1007/978-1-4612-4380-9_5>).
    Functions are compatible with 'ggplot2' and 'dplyr'.
License: MIT + file LICENSE
Depends: R (>= 4.1.0)
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: car, crayon, dplyr, FSA, ggplot2, ggdist, ggExtra, nortest,
        purrr, RColorBrewer, scales, stats, tibble, tidyr, tidyselect,
        utils, vcd
NeedsCompilation: no
Maintainer: Luiz Garcia <luiz.cardoso@ufpr.br>
Packaged: 2026-04-24 01:37:19 UTC; Seu Computador
Author: Luiz Garcia [aut, cre] (ORCID: <https://orcid.org/0000-0002-9616-0927>)
Repository: CRAN
Date/Publication: 2026-04-28 18:30:16 UTC
Built: R 4.5.2; ; 2026-05-01 19:37:19 UTC; unix
