# Generated by roxygen2: do not edit by hand

S3method(print,test.correlation)
S3method(print,test.interaction)
export(pre.test)
export(test.anova)
export(test.chi)
export(test.correlation)
export(test.fisher)
export(test.interaction)
export(test.kruskal)
export(test.t)
export(test.tmulti)
export(test.tpaired)
export(test.u)
importFrom(RColorBrewer,brewer.pal)
importFrom(car,leveneTest)
importFrom(dplyr,"%>%")
importFrom(ggExtra,ggMarginal)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,theme_minimal)
importFrom(grDevices,gray.colors)
importFrom(purrr,map_dfr)
importFrom(scales,hue_pal)
importFrom(stats,TukeyHSD)
importFrom(stats,aggregate)
importFrom(stats,aov)
importFrom(stats,chisq.test)
importFrom(stats,complete.cases)
importFrom(stats,confint)
importFrom(stats,dist)
importFrom(stats,formula)
importFrom(stats,kruskal.test)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,p.adjust)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reformulate)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,shapiro.test)
importFrom(stats,t.test)
importFrom(stats,var.test)
importFrom(stats,wilcox.test)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(tidyselect,everything)
importFrom(utils,combn)
importFrom(utils,globalVariables)
