% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Paired_T_test.R
\name{test.tpaired}
\alias{test.tpaired}
\title{Paired t-test with advanced visualizations}
\usage{
test.tpaired(
  ...,
  title = "Paired t-test",
  xlab = "",
  ylab = "Value",
  style = c("boxplot", "violin", "mono", "halfeye"),
  connect = TRUE,
  help = FALSE,
  verbose = TRUE
)
}
\arguments{
\item{...}{Two numeric vectors of equal length, or
a data frame with exactly two numeric columns.}

\item{title}{Plot title.}

\item{xlab}{X-axis label.}

\item{ylab}{Y-axis label.}

\item{style}{Plot style:
\itemize{
\item \code{1} Premium boxplot
\item \code{2} Violin + minimal boxplot
\item \code{3} mono
\item \code{4} Half-eye (ggdist)
}}

\item{connect}{Logical. If TRUE, connects paired observations.}

\item{help}{If TRUE, displays detailed help.}

\item{verbose}{If TRUE, prints progress messages.}
}
\value{
An invisible list containing:
\describe{
\item{summary_table}{Group means and standard deviations}
\item{test_result}{t-test result object (stats::t.test)}
\item{data}{Data frame used for plotting}
\item{plot}{ggplot2 object}
}
}
\description{
Performs a paired t-test between two numeric vectors (e.g., before vs after)
or between two numeric columns of a data frame.
Includes four visualization styles (boxplot, violin, mono, and half-eye).
}
\examples{
before <- c(13, 12, 15, 14)
after  <- c(9, 11, 10, 10)
test.tpaired(before, after)

}
