% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/U_test.R
\name{test.u}
\alias{test.u}
\title{Mann-Whitney U Test}
\usage{
test.u(
  ...,
  title = "Mann-Whitney Test",
  xlab = "Group",
  ylab = "Value",
  style = c("boxplot", "violin", "mono", "halfeye"),
  help = FALSE,
  verbose = TRUE
)
}
\arguments{
\item{...}{Two numeric vectors or a data.frame with two numeric columns.}

\item{title}{Plot title. Default: "Mann-Whitney Test".}

\item{xlab}{Label for x-axis. Default: "Group".}

\item{ylab}{Label for y-axis. Default: "Value".}

\item{style}{Plot aesthetic style.}

\item{help}{Logical. If TRUE, prints a detailed explanation. Default: FALSE.}

\item{verbose}{Logical. If TRUE, prints detailed messages. Default: TRUE.}
}
\value{
Invisible list with:
\describe{
\item{summary}{Group-wise statistical summary}
\item{test}{Test result (htest object)}
\item{plot}{ggplot2 visualization object}
}
}
\description{
Performs the Mann-Whitney (Wilcoxon rank-sum) test for comparing two independent groups,
with statistical summary and graphical visualization.
}
\examples{
x <- c(1, 3, 5, 6)
y <- c(7, 8, 9, 12)
data <- data.frame(groupA = x, groupB = y)
test.u(data)
}
